@@ -2,24 +2,26 @@ import commands
 import os.path
 import fnmatch
 import gtk
-import gobject
 import random
 import fnmatch
+import gtk.gdk
+from mutagen.id3 import ID3, ID3NoHeaderError
 
-VERSION = "0.5.3"
+VERSION = "0.5.4"
 IS_MAEMO = commands.getoutput("uname -m")[0:3] == "arm" # if cpu type is ARM, we are on maemo
 
 # general settings
-db_file = os.path.expanduser("~/.musicdb")
 known_exts = ("mp3", "ogg", "mp4", "wma")
 
 # device specific settings
 if IS_MAEMO:
     MAX_VOL = 10.0
     img_path = "/usr/share/youamp/%s"
+    db_file = os.path.expanduser("~/.musicdb")
 else: 
     MAX_VOL = 4.0
     img_path = "data/%s"
+    db_file = os.path.expanduser("~/.local/youamp/musicdb")
 
 class Playlist(gtk.ListStore):    
     def __init__(self, playlist=None):
@@ -95,3 +97,26 @@ class Song(dict):
         
         return os.path.join(dir, img)
 
+    def cover_image(self, size):
+        path = self.cover_uri()
+
+        if path is None:
+            # no image in song directory
+            # try to load from ID3
+            try:
+                id3 = ID3(self.uri[7:])
+                if len(id3.getall('APIC')) > 0:
+                    apic = id3.getall('APIC')[0]
+                    loader = gtk.gdk.PixbufLoader()
+                    loader.set_size(*size)
+                    loader.write(apic.data)
+                    loader.close()
+                    return loader.get_pixbuf()
+            except ID3NoHeaderError:
+                pass
+
+            return None
+        else:
+            # use the image in song directory
+            return gtk.gdk.pixbuf_new_from_file_at_size(path, *size)
+
