@@ -32,7 +32,8 @@ class Config(gconf.Client):
     def __setitem__(self, k, v):
         """
         @param k: key
-        @param v: value. None for unsetting the key"""
+        @param v: value. None for unsetting the key
+        """
         if v is None:
             self.unset(self._base_path + k)
         else:
