@@ -9,7 +9,7 @@ from youamp.ui.window import Window, Menu
 from youamp.ui.about import AboutDialog
 from youamp.ui.preferences import Preferences
 
-from youamp import Playlist, IS_MAEMO, VERSION
+from youamp import IS_MAEMO, VERSION
 
 from youamp.library import Library, check_db
 from youamp.player import Player
@@ -88,9 +88,12 @@ class Controller:
         if self._config["shuffle"]:
             self._player.playlist.shuffle(True)
 
-        # restore config
-        if self._player.tracks() > 0:
+        # restore playlist pos
+        try:
             self._player.load_track()
+        except IndexError:
+            # track might have been deleted
+            pass
         
         self._window.view.restore()
     
@@ -187,7 +190,7 @@ class Controller:
     def quit(self, caller=None):        
         if self._scrobbler.is_connected():
             try:
-                print self._scrobbler.flush()
+                self._scrobbler.flush()
             except urllib2.URLError, e:
                 sys.stderr.write("lastfm.submit: %s\n" % e)
         
