@@ -143,6 +143,9 @@ class Library(GObject):
                 except ID3NoHeaderError:
                     sys.stderr.write("Bad ID3 Header, skipping: %s\n" % path)
                     continue
+                except IOError, e:
+                    sys.stderr.write(str(e)+"\n")
+                    continue
             else:
                 f = mutagen.File(path)
                 
@@ -201,6 +204,7 @@ def check_db():
         con.execute("ALTER TABLE songs ADD COLUMN playcount INT")
 
 def setup_db():
+    os.makedirs(os.path.dirname(db_file))
     con = sqlite3.connect(db_file)
 
     con.execute("CREATE TABLE songs (uri TEXT, title TEXT, artist TEXT, album TEXT, genre TEXT, tracknumber INT, playcount INT, date TEXT)")
