@@ -24,9 +24,13 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>."""
 
 class AboutDialog(gtk.AboutDialog):
     def __init__(self, parent):
+        self._created = False
+        self._parent = parent
+    
+    def _create(self):
         gtk.AboutDialog.__init__(self)
         
-        self.set_transient_for(parent)
+        self.set_transient_for(self._parent)
         
         self.set_name("YouAmp")
         self.set_version(VERSION)
@@ -49,3 +53,10 @@ class AboutDialog(gtk.AboutDialog):
             
         self.connect("response", self.hide_on_delete)
         self.connect("delete-event", self.hide_on_delete)
+    
+    def cshow(self):
+        if not self._created:
+            self._create()
+            self._created = True
+        
+        self.show()
