@@ -1,6 +1,6 @@
 import gtk
 import gtk.gdk
-import md5
+from hashlib import md5
 
 from youamp import VERSION
 
@@ -156,7 +156,7 @@ class Preferences(gtk.Window):
         if txt == "******":
             return
 
-        self.config["lastfm-pass"] = md5.md5(txt).hexdigest()
+        self.config["lastfm-pass"] = md5(txt).hexdigest()
         self._try_login()
  
     def _on_mf_changed(self, caller):
